==> 4.7.4.tar.gz: terraform-provider-decort/samples/cloudbroker/pcidevice/resource_pcidevice/main.tf <==
/*
Пример использования
Ресурса pdidevice
Ресурс позволяет:
1. Создавать устройство
2. Редактировать устройство
3. Удалять устройство
*/

#Расскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*
terraform {
  required_providers {
    decort = {
      source  = "basis/decort/decort"
      version = "<VERSION>"
    }
  }
}
*/

provider "decort" {
  authenticator = "decs3o"
  #controller_url = <DECORT_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DECORT_SSO_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}

resource "decort_cb_pcidevice" "pd" {
  #имя устройства
  #обязательный параметр
  #тип - строка
  name = "test_device"

  #путь до устройства
  #обязательный параметр
  #тип - строка
  hw_path = "0000:01:00.0"

  #описание устройства
  #необязательный параметр
  #тип - строка
  #description = "test desc"

  #id ресурсной группы устройства
  #обязательный параметр
  #тип - целое число
  rg_id = 1111

  #id стака устройства
  #обязательный параметр
  #тип - целое число
  stack_id = 11

  #доступность устройства
  #опциональный параметр
  #может использоваться на созданном ресурсе
  #тип - булев
  #enable = false

  #принудительное отключение устройства
  #опциональный параметр
  #может использоваться на созданном ресурсе
  #тип - булев
  #force_disable = true

  #принудительное удаление устройства
  #опциональный параметр
  #используется при удалении ресурса
  #тип - булев
  #force_delete = true

  #id устройства
  #опциональный параметр
  #позволяет "восстановить" состояние ресурса терраформа на локальной машине
  #тип - целое число
  #device_id = 86
}

output "test" {
  value = decort_cb_pcidevice.pd
}

==> 4.9.0.tar.gz: terraform-provider-decort/samples/cloudbroker/pcidevice/resource_pcidevice/main.tf <==
/*
Пример использования
Ресурса pdidevice
Ресурс позволяет:
1. Создавать устройство
2. Редактировать устройство
3. Удалять устройство
*/

#Раскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*
terraform {
  required_providers {
    decort = {
      source  = "basis/decort/decort"
      version = "<VERSION>"
    }
  }
}
*/

provider "decort" {
  authenticator = "decs3o"
  #controller_url = <DECORT_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DECORT_SSO_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}

resource "decort_cb_pcidevice" "pd" {
  #имя устройства
  #обязательный параметр
  #тип - строка
  #используется при создании
  name = "test_device"

  #путь до устройства
  #обязательный параметр
  #тип - строка
  #используется при создании
  hw_path = "0000:01:00.0"

  #описание устройства
  #опциональный параметр
  #тип - строка
  #используется при создании
  #description = "test desc"

  #id ресурсной группы устройства
  #обязательный параметр
  #тип - целое число
  #используется при создании
  rg_id = 1111

  #id стака устройства
  #обязательный параметр
  #тип - целое число
  #используется при создании
  stack_id = 11

  #доступность устройства
  #опциональный параметр
  #тип - булев
  #используется при создании и обновлении
  #enable = false

  #принудительное отключение устройства
  #опциональный параметр
  #может использоваться на созданном ресурсе
  #тип - булев
  #используется при обновлении
  #force_disable = true

  #принудительное удаление устройства
  #опциональный параметр
  #тип - булев
  #используется при удалении
  #force_delete = true

  #id устройства
  #опциональный параметр
  #позволяет "восстановить" состояние ресурса терраформа на локальной машине
  #тип - целое число
  #device_id = 86
}

output "test" {
  value = decort_cb_pcidevice.pd
}
